using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using NETOLib;

/**
 * When using visual studio.net to import the neto.dll COM control the generated .NET wrapper has the following problems.
 * - ShowPoll Events do not work.
 * - Progress Events do not work.
 * - ProtocolMessage Events do not work.  
 * 
 * The dll supplied wit this demo fixes these problems.
 * This dll is a replacement for the visual studio.net generated dll
 * To use this DLL remove the references to the existing NETOLib from the project
 * and replace it with a reference to the supplied DLL.
 * Please don't forget to add this version of NETOLib.DLL to youre distribution package.
 *
 * 
 * Used settings are for a OPH1001 / CRD1001 
 * Baudrate = 115200, 
 * IdDADevice = NoneIrDA. 
 * 
 * See Neto help file for detailed infomation of all properties and events.
 **/

namespace NetoDemo
{
    public partial class MainForm : Form
    {
        private NetoCtl aNetoControl = new NetoCtl();

        private delegate void UpdateTextDelegate(String s);
        string filenames;

        public MainForm()
        {
            InitializeComponent();
            this.Text += " (Version: EGF31140)";

            filenames = "";

            aNetoControl.Baudrate = 115200;
            rtxtbLog.AppendText("Baudrate\t\t: 115200\n");

            aNetoControl.IrDADevice = enumIRDADev.NoneIrda;
            rtxtbLog.AppendText("IdDADevice\t: None\n");

            aNetoControl.PollSpeed = 1000;
            rtxtbLog.AppendText("PollSpeed\t: 1s\n");

            aNetoControl.ShowPoll += new _INetoCtlEvents_ShowPollEventHandler(aNetoControl_ShowPoll);
            aNetoControl.Progress += new _INetoCtlEvents_ProgressEventHandler(aNetoControl_Progress);
            aNetoControl.ProtocolMessage += new _INetoCtlEvents_ProtocolMessageEventHandler(aNetoControl_ProtocolMessage);

            int res = aNetoControl.AddToList2("&&&&&&", filenames, "c:\\temp", enumDownType.downAppend, enumComType.comDownload);
        }

        private void btnStartPolling_Click(object sender, EventArgs e)
        {
            int res = aNetoControl.StartListNeto2();

            rtxtbLog.Text += "StartListNeto2 returned " + res + "\r\n";

            if (aNetoControl.IsProtocolRunning() == 0)
            {
                rtxtbLog.Text += "Protocol NOT running!" + "\r\n";
            }
            else
            {
                rtxtbLog.Text += "Protocol running!" + "\r\n";
            }
        }
        
        private void btnStopPolling_Click(object sender, EventArgs e)
        {
            aNetoControl.StopRunning();
        }
        
        
        void UpdateText(String s)
        {
            rtxtbLog.AppendText( s );
            rtxtbLog.ScrollToCaret();
        }


        private void aNetoControl_Progress(short Current, short Total, short COMport)
        {
            Invoke( new UpdateTextDelegate( UpdateText ), "ProgressEvent: " + Current + "of" + Total + "\r\n");
        }

        private void aNetoControl_ProtocolMessage(short msgCode, string strMessage, short final, short COMport)
        {
            Invoke(new UpdateTextDelegate(UpdateText), "MessageEvent: " + strMessage + "\r\n");
        }

        private void aNetoControl_ShowPoll(string PollId, short COMport)
        {
            Invoke( new UpdateTextDelegate( UpdateText ),  "PollEvent: " + "COM" + COMport + ", " + PollId + "\r\n");
        }
    }
}